@@ -123,7 +123,7 @@ class WifiConf():
                             interface=self.wlan) 
             myFinder.connection()
             self.connected.value=1
-            print("connected!")
+            #print("connected!")
         print("ok")
 
     def reset_ap(self):
@@ -133,7 +133,7 @@ class WifiConf():
 
     def start(self):
         try:
-            print("running? "+str(self.access_point.is_running()))
+            #print("running? "+str(self.access_point.is_running()))
             app.run(host=self.host, port=self.port)
         
         except Exception as e:
